<?php

App::uses('AppHelper', 'View/Helper');

class OrderHelper extends AppHelper {

/**
 * Get a specific item of order data from the order data array.
 * @param  array         $orderData The order data array as returned as part of an order.
 * @param  array         $dataName  The name of the data you want to get.
 * @return string|array             The data if found, false if not found and null if no order data was provided
 */
	public function getOrderData($orderData, $dataName) {
		if (empty($orderData)) {
			return null;
		}

		$data = Hash::combine($orderData, '{n}.name', '{n}.data');

		if (!empty($data[$dataName])) {
			return $data[$dataName];
		}

		return false;
	}

/**
 * Get the price to display for an item. The item only needs to be provided if you want to only get the price of the
 * item. If EvBulkDiscount is installed then you can use the additional parameters to get the original price.
 * @param  array   $item             The array of a single order item.
 * @param  boolean $getOriginalPrice True if you want the original price of an item. False by default.
 * @param  array   $orderData        Only provide if you want the original price. The order data array as provided
 *                                   as part of an order.
 * @return string                    The price to display.
 */
	public function displayOrderItemUnitPrice($item, $getOriginalPrice = false, $orderData = []) {
		//Get the original prices from the order data
		if ($getOriginalPrice && !empty($item['model']) && !empty($item['model_id']) && !empty($orderData)) {
			$orderItemPath = $item['model'] . '.' . $item['model_id'];

			$originalPriceData = $this->getOrderData($orderData, 'original_price');

			if (!empty($originalPriceData) && !is_array($originalPriceData)) {
				$originalPriceData = json_decode($originalPriceData, true);

				if (!empty($originalPriceData[$orderItemPath]['unit_price_incTax'])) {
					return $originalPriceData[$orderItemPath]['unit_price_incTax'];
				}
			}
		}

		//Get the unit price for an item. If the taxed value is available then use that. There are potentially 2 tax
		//fields because the basket incTax field is calculated so doesn't include the underscore whereas the order
		//in_tax field is a database field so is underscored. This helper needs to work with both for compatability.
		$price = $item['unit_price'];
		if (!empty($item['unit_price_inc_tax']) && $item['unit_price_inc_tax'] > 0) {
			$price = $item['unit_price_inc_tax'];
		} elseif (!empty($item['unit_price_incTax']) && $item['unit_price_incTax'] > 0) {
			$price = $item['unit_price_incTax'];
		}

		return $price;
	}
}
